import React, { Fragment } from 'react'
import styled from 'styled-components'
import { isEmpty, get, last } from 'lodash'
import {
  Text,
  ReviewerDetails,
  ManuscriptHeader,
  ManuscriptAssignHE,
  ManuscriptMetadata,
  HandlingEditorAnswer,
  ManuscriptDetailsTop,
  ManuscriptEicDecision,
  paddingHelper,
} from 'pubsweet-component-faraday-ui'

const eicDecisions = [
  { value: 'return-to-handling-editor', label: 'Return to Handling Editor' },
  { value: 'publish', label: 'Publish' },
  { value: 'reject', label: 'Reject' },
]

const messagesLabel = {
  'return-to-handling-editor': 'Comments for Handling Editor',
  publish: 'Comments for Author',
  reject: 'Comments for Author',
}

const ManuscriptLayout = ({
  history,
  assignHE,
  revokeHE,
  currentUser,
  getSignedUrl,
  editorInChief,
  handlingEditors,
  createRecommendation,
  hasResponseToReviewers,
  editorialRecommendations,
  journal = {},
  collection = {},
  fragment = {},
  isFetching,
  formValues,
  toggleAssignHE,
  heExpanded,
  toggleHEResponse,
  heResponseExpanded,
  onHEResponse,
  onInviteReviewer,
  invitationsWithReviewers,
  onResendReviewerInvite,
  onRevokeReviewerInvite,
}) => (
  <Root pb={1}>
    {!isEmpty(collection) && !isEmpty(fragment) ? (
      <Fragment>
        <ManuscriptDetailsTop
          collection={collection}
          currentUser={currentUser}
          fragment={fragment}
          getSignedUrl={getSignedUrl}
          history={history}
        />

        <ManuscriptHeader
          collection={collection}
          currentUser={currentUser}
          editorInChief={editorInChief}
          fragment={fragment}
          handlingEditors={handlingEditors}
          inviteHE={toggleAssignHE}
          isFetching={isFetching.editorsFetching}
          journal={journal}
          resendInvitation={assignHE}
          revokeInvitation={revokeHE}
        />

        <ManuscriptMetadata
          currentUser={currentUser}
          fragment={fragment}
          getSignedUrl={getSignedUrl}
        />

        {get(currentUser, 'isInvitedHE', false) && (
          <HandlingEditorAnswer
            expanded={heResponseExpanded}
            formValues={formValues.heInvitation}
            onResponse={onHEResponse}
            toggle={toggleHEResponse}
          />
        )}

        <ManuscriptAssignHE
          assignHE={assignHE}
          currentUser={currentUser}
          expanded={heExpanded}
          handlingEditors={handlingEditors}
          isFetching={isFetching.editorsFetching}
          toggle={toggleAssignHE}
        />

        {get(currentUser, 'permissions.canMakeDecision', false) && (
          <ManuscriptEicDecision
            formValues={get(formValues, 'eicDecision')}
            isFetching={isFetching.recommendationsFetching}
            messagesLabel={messagesLabel}
            mt={2}
            options={
              get(collection, 'status', 'submitted') === 'submitted'
                ? [last(eicDecisions)]
                : eicDecisions
            }
            submitDecision={createRecommendation}
          />
        )}

        {get(currentUser, 'permissions.canInviteReviewers', false) && (
          <ReviewerDetails
            fragment={fragment}
            invitations={invitationsWithReviewers}
            onInviteReviewer={onInviteReviewer}
            onResendReviewerInvite={onResendReviewerInvite}
            onRevokeReviewerInvite={onRevokeReviewerInvite}
          />
        )}
      </Fragment>
    ) : (
      <Text>Loading...</Text>
    )}
  </Root>
)

export default ManuscriptLayout

// #region styles
const Root = styled.div`
  overflow-y: visible;
  min-height: 70vh;
  ${paddingHelper};
`
// #endregion
